API Documentation
=================

Most sacc interface is done through the sacc.Sacc object, including tracer, covariance, and data point construction.
One notable exception is the specification of winow functions, which is done manually.s

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   sacc
   tracers
   windows
   covariance
   data_types
   utils